## Virtual Resource Management in Cloudless System

- singleton.py: provides Singleton metaclass that is used in various systems.
- tinydb_wrapper.py: provides TinyDbWrapper class that is used to interact with tinydb, and encapsulates useful methods to store/retrieve/remove hosts as well as necessary daemon information of each hosts.
- helper.py: provides useful helper methods (e.g., convert yaml to json, extract docker configuration from yaml)